Core of runs (core package)
===========================

CoreRun
---------------------------

Class is responsible for run of one optimization of GADMA.

.. automodule:: gadma.core.core_run
   :members:
   :undoc-members:
   :show-inheritance:

SharedDict
------------------------------

.. automodule:: gadma.core.shared_dict
   :members:
   :undoc-members:
   :show-inheritance:

Core
----------------------

.. automodule:: gadma.core.core
   :members:
   :undoc-members:
   :show-inheritance:


Functions for drawing and code generation in main function of core
------------------------------------------------------------------

.. automodule:: gadma.core.draw_and_generate_code
   :members:
   :undoc-members:
   :show-inheritance:



